D4rtBridgeBuilder class

Builder that generates D4rt bridges from build.yaml configuration.

Configuration is specified in build.yaml under targets.$default.builders:

targets:
  $default:
    builders:
      tom_d4rt_generator:d4rt_bridge_builder:
        enabled: true
        options:
          name: my_package
          modules:
            - name: all
              barrelFiles: [lib/my_package.dart]
              outputPath: lib/src/d4rt_bridges/my_package_bridges.b.dart
          generateBarrel: true
          barrelPath: lib/d4rt_bridges.b.dart
          generateDartscript: true
          dartscriptPath: lib/dartscript.b.dart

The builder triggers on any .dart file change and regenerates all bridges.

Constructors

D4rtBridgeBuilder(BridgeConfig? config)
Creates a new D4rtBridgeBuilder with the given config.
const

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
config BridgeConfig?
The configuration for this builder.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited