toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buf = StringBuffer('D4rtTestResult(\n');
  buf.writeln('  success: $success');
  buf.writeln('  timedOut: $timedOut');
  buf.writeln('  exitCode: $exitCode');
  if (exceptions.isNotEmpty) {
    buf.writeln('  exceptions: [');
    for (final e in exceptions) {
      buf.writeln('    $e');
    }
    buf.writeln('  ]');
  }
  if (processOutput.isNotEmpty) {
    buf.writeln(
      '  processOutput: ${processOutput.length > 200 ? '${processOutput.substring(0, 200)}...' : processOutput}',
    );
  }
  if (processError.isNotEmpty) {
    buf.writeln(
      '  processError: ${processError.length > 200 ? '${processError.substring(0, 200)}...' : processError}',
    );
  }
  buf.writeln(')');
  return buf.toString();
}