defaultTimeout property
Default timeout for test execution.
If a script takes longer than this, the subprocess is killed and
D4rtTestResult.timedOut is set to true. Default: 3 seconds.
Implementation
final Duration defaultTimeout;
Default timeout for test execution.
If a script takes longer than this, the subprocess is killed and
D4rtTestResult.timedOut is set to true. Default: 3 seconds.
final Duration defaultTimeout;