toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buf = StringBuffer('IssueTestResult(\n');
  buf.writeln('  generationSucceeded: $generationSucceeded');
  buf.writeln('  classesGenerated: $classesGenerated');
  if (generationErrors.isNotEmpty) {
    buf.writeln('  generationErrors: $generationErrors');
  }
  if (generationWarnings.isNotEmpty) {
    buf.writeln('  generationWarnings: $generationWarnings');
  }
  buf.writeln('  scriptSucceeded: $scriptSucceeded');
  if (scriptResult != null) buf.writeln('  scriptResult: $scriptResult');
  if (scriptError != null) buf.writeln('  scriptError: $scriptError');
  if (bridgeCompiles != null) {
    buf.writeln('  bridgeCompiles: $bridgeCompiles');
  }
  if (compilationErrors.isNotEmpty) {
    buf.writeln('  compilationErrors: $compilationErrors');
  }
  buf.writeln(')');
  return buf.toString();
}