TestModuleConfig class
Configuration for a bridge module in the test project.
Constructors
Properties
- barrelFile → String
-
Barrel file path relative to the project (e.g., 'lib/test_pkg.dart').
final
-
excludeClasses
→ List<
String> -
Classes to exclude from generation.
final
-
excludeConstructors
→ List<
String> -
Constructors to exclude, qualified as
ClassName.ctorName(ClassName.newfor the default constructor).final -
excludeSourcePatterns
→ List<
String> -
Source patterns to exclude.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Module name (used in the bridge class name).
final
- outputPath → String
-
Output path for the generated bridge file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited