sourceImports property
Multiple barrel file import paths for source code. Each barrel is imported with a unique prefix ($pkg, $pkg2, etc.). When set, sourceImport is ignored.
Implementation
final List<String> sourceImports;
Multiple barrel file import paths for source code. Each barrel is imported with a unique prefix ($pkg, $pkg2, etc.). When set, sourceImport is ignored.
final List<String> sourceImports;