PreviewedChange enum
How a previewed write relates to the file already in the package.
Values
- created → const PreviewedChange
-
The package has no such file.
const PreviewedChange('would create') - changed → const PreviewedChange
-
The package has the file, and its content differs beyond the
// Generated:line.const PreviewedChange('would change') - unchanged → const PreviewedChange
-
The package has the file with the same content, apart from the
// Generated:line.const PreviewedChange('unchanged')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
How a report should describe the change.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PreviewedChange> - A constant List of the values in this enum, in order of their declaration.