projectPath property
Path to the project directory.
This must be a project with a valid pubspec.yaml and resolved
dependencies. Bridge files and the test runner are generated into
this directory based on the BridgeConfig paths.
Implementation
final String projectPath;