IssueTestResult class
Result of running an issue test.
Constructors
-
IssueTestResult({required bool generationSucceeded, String? generatedCode, List<
String> generationErrors = const [], List<String> generationWarnings = const [], int classesGenerated = 0, required bool scriptSucceeded, dynamic scriptResult, Object? scriptError, StackTrace? scriptStackTrace, bool? bridgeCompiles, List<String> compilationErrors = const []}) -
const
Properties
- bridgeCompiles → bool?
-
Whether the generated code compiles (attempted via analyzer).
final
- classesGenerated → int
-
Number of classes generated.
final
-
compilationErrors
→ List<
String> -
Compilation errors in the generated bridge code.
final
- generatedCode → String?
-
The generated bridge code (null if generation failed).
final
-
generationErrors
→ List<
String> -
Errors from bridge generation.
final
- generationSucceeded → bool
-
Whether bridge generation succeeded.
final
-
generationWarnings
→ List<
String> -
Warnings from bridge generation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issueReproduces → bool
-
Whether the issue reproduces (generation or script failed).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scriptError → Object?
-
Error from D4rt script execution (null if it succeeded).
final
- scriptResult → dynamic
-
The return value from the D4rt script (null if it failed).
final
- scriptStackTrace → StackTrace?
-
Stack trace from D4rt script execution error.
final
- scriptSucceeded → bool
-
Whether the D4rt script executed successfully.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited