ResolutionMismatch class
One package a fixture resolves differently from its host.
Constructors
- ResolutionMismatch({required String fixturePath, required String package, required String hostVersion, required String fixtureVersion})
Properties
- fixturePath → String
-
The fixture project that resolved package at fixtureVersion.
final
- fixtureVersion → String
-
What the fixture resolves, and therefore compiles the host's lib against.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostVersion → String
-
What the host resolves — the version its
lib/is written against.final - package → String
-
Package name as both locks spell it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited