ConstructorInfo class
Information about a constructor.
Constructors
-
ConstructorInfo({String? name, required List<
ParameterInfo> parameters, bool isFactory = false, bool isConst = false}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConst → bool
-
final
- isFactory → bool
-
final
- name → String?
-
final
-
parameters
→ List<
ParameterInfo> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited