ExportInfo class
Information about an export directive from a barrel file.
Constructors
Properties
- barrelUri → String?
-
The barrel file URI that this export was found in.
Used to determine which import prefix to use for classes from this source.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hideClause
→ List<
String> ? -
Symbols hidden from the export (from
hideclause).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
showClause
→ List<
String> ? -
Symbols shown from the export (from
showclause).final - sourcePath → String
-
The absolute path to the exported source file.
final
Methods
-
copyWith(
{String? barrelUri, List< String> ? hideClause, List<String> ? showClause}) → ExportInfo - Create a copy with a different barrelUri and/or merged clauses.
-
isClassExported(
String className) → bool - Deprecated: use isSymbolExported instead.
-
isSymbolExported(
String symbolName) → bool - Whether a symbol (class, enum, function, variable, typedef) is exported.
-
mergeWithParent(
{List< String> ? parentShowClause, List<String> ? parentHideClause}) → ExportInfo - Merge this ExportInfo's show/hide clauses with parent clauses.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited