GlobalFunctionInfo class
Information about a top-level function for bridging.
Constructors
-
GlobalFunctionInfo({required String name, required String returnType, Set<
String> returnTypeImportUris = const {}, Map<String, String> returnTypeToUri = const {}, required List<ParameterInfo> parameters, required String sourceFile, bool hasTypeParameters = false, Map<String, String?> typeParameters = const {}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTypeParameters → bool
-
Whether the function has type parameters (generics).
final
- name → String
-
final
-
parameters
→ List<
ParameterInfo> -
final
- returnType → String
-
final
-
returnTypeImportUris
→ Set<
String> -
Import URIs needed for the return type.
final
-
returnTypeToUri
→ Map<
String, String> -
Map of type name to import URI for resolving return type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceFile → String
-
final
-
typeParameters
→ Map<
String, String?> -
Type parameters and their bounds for this function (e.g., {'T': 'Object', 'E': 'TomObject'}).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited