GlobalVariableInfo class
Information about a top-level variable for bridging.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSetter → bool
-
GEN-054: Whether this getter has a corresponding setter.
final
- isConst → bool
-
final
- isFinal → bool
-
final
- isGetter → bool
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceFile → String
-
final
- type → String
-
final
-
typeImportUris
→ Set<
String> -
Import URIs needed for the type.
final
-
typeToUri
→ Map<
String, String> -
Map of type name to import URI for resolving type.
final
Methods
-
copyWith(
{bool? hasSetter}) → GlobalVariableInfo - Creates a copy with updated hasSetter value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited